@@ -1,4 +1,13 @@
 require 'gon'
+
+# We don't require rails for specs, but jbuilder works only in rails.
+# And it checks version of rails. I've decided to configure jbuilder for rails v4
+module Rails
+  module VERSION
+    MAJOR = 4
+  end
+end
+
 require 'jbuilder'
 require 'rabl'
 require 'rabl-rails'
@@ -14,9 +23,11 @@ def ensure_rabl_is_loaded
     load 'rabl.rb'
     load 'rabl/version.rb'
     load 'rabl/helpers.rb'
+    load 'rabl/sources.rb'
     load 'rabl/partials.rb'
-    load 'rabl/engine.rb'
+    load 'rabl/multi_builder.rb'
     load 'rabl/builder.rb'
+    load 'rabl/engine.rb'
     load 'rabl/configuration.rb'
     load 'rabl/renderer.rb'
     load 'rabl/cache_engine.rb'
@@ -27,14 +38,17 @@ end
 def ensure_rabl_rails_is_loaded
   Object.send(:remove_const, :Rabl) if defined? Rabl
   unless defined? RablRails
-    load 'rabl-rails/template.rb'
-    load 'rabl-rails/condition.rb'
-    load 'rabl-rails/compiler.rb'
-    load 'rabl-rails/renderers/base.rb'
-    load 'rabl-rails/renderers/json.rb'
     load 'rabl-rails/renderer.rb'
-    load 'rabl-rails/library.rb'
+    load 'rabl-rails/helpers.rb'
+    load 'rabl-rails/configuration.rb'
+    load 'rabl-rails/nodes/node.rb'
+    load 'rabl-rails/nodes/attribute.rb'
+    load 'rabl-rails/compiler.rb'
+    load 'rabl-rails/renderers/hash.rb'
+    load 'rabl-rails/renderers/json.rb'
     load 'rabl-rails.rb'
+    load 'rabl-rails/template.rb'
+    load 'rabl-rails/library.rb'
   end
 end
 
